<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.2/1886137
 */

return [
    'router' => [
        'routes' => [
            'comments' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/comments?(/(?P<topic>.*))?',
                    'spec'     => '/comments/%topic%',
                    'defaults' => [
                        'controller' => Comments\Controller\IndexController::class,
                        'action'     => 'index',
                        'topic'      => null
                    ],
                ],
            ],
            'add-comment' => [
                'type' => 'Zend\Router\Http\Segment',
                'options' => [
                    'route'    => '/comment[s]/add[/]',
                    'defaults' => [
                        'controller' => Comments\Controller\IndexController::class,
                        'action'     => 'add'
                    ],
                ],
            ],
            'edit-comment' => [
                'type' => 'Zend\Router\Http\Segment',
                'options' => [
                    'route'    => '/comment[s]/edit/:comment[/]',
                    'defaults' => [
                        'controller' => Comments\Controller\IndexController::class,
                        'action'     => 'edit'
                    ],
                ],
            ],
        ],
    ],
    'controllers' => [
        'factories' => [
            Comments\Controller\IndexController::class => Application\Controller\IndexControllerFactory::class,
        ],
    ],
    'view_manager' => [
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ],
    'view_helpers' => [
        'factories' => [
            Application\View\Helper\ViewHelperFactory::COMMENTS => Application\View\Helper\ViewHelperFactory::class,
        ],
    ],
    'mentions' => [
        'mode'            => 'global',     // one of 'disabled' 'global' 'projects'.
        // If disabled - no @mentioning will be enabled,
        // 'global' - enables @mention dropdown in all comment sections
        // 'projects' - enables dropdown in comment sections in a project
        // that are part of a project
        'usersBlacklist'  => [],      // array of users that should never end up on the user @mention dropdown
        'groupsBlacklist' => [],      // array of groups that should never end up on the user @mention dropdown.
        // supports full regex, with the exception of an alphanumeric term, which
        // will be treated as an exact match. 'jim' will match 'jim' exactly but
        // '^jim' will match all strings starting with 'jim' and 'jim$' will match
        // all strings ending in 'jim'.
    ],
    'comments' => [
        'threading' => [
            'max_depth' => 4
        ],
        'show_id'    => false,
        'notification_delay_time' => 1800,               // Default to 30 minutes 1800 seconds.
    ]
];
